@@ -4,7 +4,10 @@ from typing import TYPE_CHECKING
 
 from django.apps import apps as django_apps
 from edc_constants.constants import COMPLETE, YES
+from edc_randomization.constants import RANDOMIZED
 from edc_randomization.site_randomizers import site_randomizers
+from edc_randomization.utils import get_object_for_subject
+from edc_registration.models import RegisteredSubject
 from edc_utils import get_utcnow
 from intecomm_form_validators import IN_FOLLOWUP
 
@@ -13,7 +16,10 @@ from .group_eligibility import assess_group_eligibility
 from .group_identifier import GroupIdentifier
 
 if TYPE_CHECKING:
-    from intecomm_screening.models import PatientGroup
+    from .models import RandomizationList
+
+if TYPE_CHECKING:
+    from intecomm_screening.models import PatientGroup, PatientLog
 
 
 def randomize_group(instance: PatientGroup) -> None:
@@ -22,7 +28,6 @@ def randomize_group(instance: PatientGroup) -> None:
 
 
 class RandomizeGroup:
-
     min_group_size = 14
     subject_consent_model = "intecomm_consent.subjectconsent"
 
@@ -80,17 +85,51 @@ class RandomizeGroup:
             ]
         )
         self.instance.refresh_from_db()
-        self.update_patient_log_and_consent()
+        self.update_patient_logs_and_consents()
 
-    def update_patient_log_and_consent(self):
+    @property
+    def randomization_list_obj(self) -> RandomizationList:
+        return get_object_for_subject(
+            self.instance.group_identifier,
+            "default",
+            identifier_fld="group_identifier",
+            label="group",
+        )
+
+    def update_patient_logs_and_consents(self):
         for patient in self.instance.patients.all():
-            patient.group_identifier = self.instance.group_identifier
-            patient.save()
-            subject_consent = self.subject_consent_model_cls.objects.get(
-                subject_identifier=patient.subject_identifier
-            )
-            subject_consent.group_identifier = self.instance.group_identifier
-            subject_consent.save()
+            self.update_patient_log(patient)
+            self.update_subject_consent(patient)
+            self.update_registered_subject(patient)
+
+    def update_patient_log(self, patient_log: PatientLog):
+        patient_log.group_identifier = self.instance.group_identifier
+        patient_log.save()
+
+    def update_subject_consent(self, patient_log: PatientLog):
+        subject_consent = self.subject_consent_model_cls.objects.get(
+            subject_identifier=patient_log.subject_identifier
+        )
+        subject_consent.group_identifier = self.instance.group_identifier
+        subject_consent.save()
+
+    def update_registered_subject(self, patient_log: PatientLog):
+        randomization_datetime = self.randomization_list_obj.allocated_datetime
+        rs_obj = RegisteredSubject.objects.get(
+            subject_identifier=patient_log.subject_identifier
+        )
+        rs_obj.randomization_datetime = randomization_datetime
+        rs_obj.sid = self.randomization_list_obj.sid
+        rs_obj.registration_status = RANDOMIZED
+        rs_obj.randomization_list_model = self.randomization_list_obj._meta.label_lower
+        rs_obj.save(
+            update_fields=[
+                "randomization_datetime",
+                "sid",
+                "registration_status",
+                "randomization_list_model",
+            ]
+        )
 
     @property
     def subject_consent_model_cls(self):
